<?php
/*
Plugin Name: Site Plugin for danixland.net
Description: Site specific code changes for danixland.net
*/

/**
 * Disable admin bar sitewide
 */
show_admin_bar(__return_false());

/**
 * Allow Shortcodes inside the html widget
 */
add_filter( 'widget_text', 'do_shortcode' );

/**
 * make sure the links menu in the admin is visible
 */
add_filter( 'pre_option_link_manager_enabled', '__return_true' );

/**
 * The gravatar shortcode
 *
 * @param email $email email address used to retrieve the gravatar image
 * @return string HTML the image tag which will display the gravatar image.
 *
 */
function danix_gravatar( $atts ) {
    extract(shortcode_atts(array(
        'email'        => '',
        'size'         => '200',
        'default'      => '',
        'alt'          => ''
    ), $atts));

    if( empty($email) )
        return '';

    $output = get_avatar($email, $size, $default, $alt);

    return $output;
}
add_shortcode('gravatar', 'danix_gravatar');

/**
 * The download button shortcode
 *
 * @param url $link link address.
 * @param string $linkname text that will be displayed by the button.
 * @return string HTML the link tag that will be rendered to the page.
 *
 */
function danix_download_button( $atts ) {
    extract(shortcode_atts(array(
        'link'      => '',
        'linkname'  => ''
    ), $atts));

    if ( empty($link) )
        return '';

    $output = sprintf(
        '<a href="%s" class="download_button">%s</a>',
        $link,
        $linkname
    );

    return $output;
}
add_shortcode('download', 'danix_download_button');

/**
 * The google analytics code
 *
 */
function danix_google_anal() {?>
<!-- Global site tag (gtag.js) - Google Analytics -->
<script async src="https://www.googletagmanager.com/gtag/js?id=UA-23882460-1"></script>
<script>
  window.dataLayer = window.dataLayer || [];
  function gtag(){dataLayer.push(arguments);}
  gtag('js', new Date());

  gtag('config', 'UA-23882460-1');
</script>
<?php }
add_action('wp_head', 'danix_google_anal', 10);

/**
 * The googlemaps shortcode
 *
 * @param width the width of the returned map
 * @param height the height of the returned map
 * @param src the url of the map you want to display
 * @return string HTML the map object
 * @since 0.57
 *
 */
function danix_gmaps($atts, $content = null) {
    extract(shortcode_atts(array(
      "width" => '640',
      "height" => '480',
      "src" => ''
    ), $atts));
    return '<iframe width="'.$width.'" height="'.$height.'" frameborder="0" scrolling="no" marginheight="0" marginwidth="0" src="'.$src.'&amp;output=embed" ></iframe>';
}
add_shortcode("googlemaps", "danix_gmaps");

